@@ -1,3 +1,5 @@
+use std::fs;
+
 /// Returns the Gut path directory as a String
 ///
 /// This function will panic if it fails to get the user's home directory.
@@ -15,8 +17,17 @@ pub fn get_gut_dir() -> String {
   format!("{}/{}", home, ".gut")
 }
 
+pub fn create_gut_dir() {
+  fs::create_dir_all(get_gut_dir()).expect("Failed to create gut directory");
+}
+
 #[cfg(test)]
 mod tests {
+  #[test]
+  fn create_gut_dir() {
+    super::create_gut_dir()
+  }
+
   #[test]
   fn get_gut_dir() {
     assert!(super::get_gut_dir().contains("/.gut"));
